==> haskell-monadlib-3.10-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monadLib
version:              3.10
visibility:           public
id:                   monadLib-3.10-vxb0fjs4p13Fu0YcCVv7A
key:                  monadLib-3.10-vxb0fjs4p13Fu0YcCVv7A
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Iavor S. Diatchki
homepage:             http://wiki.github.com/yav/monadlib
synopsis:             A collection of monad transformers.
description:          A collection of monad transformers.
category:             Monads
abi:                  f7dc329d6388efc560be9d7b9cc7659b
exposed:              True
exposed-modules:      MonadLib MonadLib.Derive MonadLib.Monads
import-dirs:          /usr/lib/ghc-8.8.3/site-local/monadLib-3.10
library-dirs:         /usr/lib/ghc-8.8.3/site-local/monadLib-3.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/monadLib-3.10
hs-libraries:         HSmonadLib-3.10-vxb0fjs4p13Fu0YcCVv7A
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-monadlib/html/monadLib.haddock
haddock-html:         /usr/share/doc/haskell-monadlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monadlib-3.10-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monadLib
version:              3.10
visibility:           public
id:                   monadLib-3.10-6h1BOxrlq8i3erP7X1lmFA
key:                  monadLib-3.10-6h1BOxrlq8i3erP7X1lmFA
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Iavor S. Diatchki
homepage:             http://wiki.github.com/yav/monadlib
synopsis:             A collection of monad transformers.
description:          A collection of monad transformers.
category:             Monads
abi:                  12cc53361ea65537ecdd156dc730ef6c
exposed:              True
exposed-modules:      MonadLib MonadLib.Derive MonadLib.Monads
import-dirs:          /usr/lib/ghc-8.10.1/site-local/monadLib-3.10
library-dirs:         /usr/lib/ghc-8.10.1/site-local/monadLib-3.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/monadLib-3.10
hs-libraries:         HSmonadLib-3.10-6h1BOxrlq8i3erP7X1lmFA
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-monadlib/html/monadLib.haddock
haddock-html:         /usr/share/doc/haskell-monadlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
